import {debugLogger as log, extendedDebugLogger as logExtended} from "../logger/log";
import UserDetails from "../util/userDetails";

/**
 * Persists user credentials from ui / flyout.
 */
export function persistUserCredentialsFromUi() {
    logExtended.debug("persistUserCredentialsFromUi", "Start");
    try{
        var credentials = window.login.getLoginMailPassword();
        logExtended.debug("persistUserCredentialsFromUi", "Credentials: Got credentials", {"credentials":credentials});
        if (credentials && credentials.email && credentials.password) {
            UserDetails.getAppSettings(function (err, res) {
                if (!err) {
                    var settings = res;
                    settings.credentials.username = credentials.email;
                    settings.credentials.password = credentials.password;
                    settings.credentials.valid = true;
                    settings.preventAutoLoginForLoggedOutUser = false;
                    settings.showDialogAskForFingerprintDecision = true;
                    UserDetails.updateAppSettings(settings, function (err, res) {
                        if(err) {
                            throw {'msg': 'persistUserCredentialsFromUi: unable to persist app settings.', 'obj': err};
                        } else {
                            logExtended.debug("persistUserCredentialsFromUi", "End: Credentials successfully saved.", {res});
                        }
                    });
                } else {
                    throw {'msg': 'persistUserCredentialsFromUi: unable to get app settings.', 'obj': err};
                }
            });
        } else {
            throw {'msg': 'persistUserCredentialsFromUi", "Error: No credentials provided from window.login.getLoginMailPassword', 'obj': credentials};
        }
    } catch(err){
        logExtended.debug("persistUserCredentialsFromUi", "End: Credentials not saved.", {'err': err});
    }
}
