import Route from "./route";

/**
 * 1. Test Suite:
 */
/** ############### Links under test ############### **/
const links = [
    {
        input: "https://www.cyberport.de",
        expectedPathName: "/",
        expectedSearchString: "",
        expectedRoute: "https://www.cyberport.de/",
        expectedNewsletterlink: false
    },
    {
        input: "https://www.cyberport.de/tools/wishlist.html?%5B%226136-13L%22%2C%226136-163%22%5D&wt_cc2=mobile_sharing-android-lo",
        expectedPathName: "/tools/wishlist.html",
        expectedSearchString: "?%5B%226136-13L%22%2C%226136-163%22%5D&wt_cc2=mobile_sharing-android-lo",
        expectedRoute: "https://www.cyberport.de/tools/wishlist.html?%5B%226136-13L%22%2C%226136-163%22%5D&wt_cc2=mobile_sharing-android-lo",
        expectedNewsletterlink: false
    },
    {
        input: "https://www.cyberport.de/apple-und-zubehoer/apple-iphone/apple/pdp/a415-18k/apple-iphone-7-32-gb-schwarz-mn8x2zd-a.html",
        expectedPathName: "/apple-und-zubehoer/apple-iphone/apple/pdp/a415-18k/apple-iphone-7-32-gb-schwarz-mn8x2zd-a.html",
        expectedSearchString: "",
        expectedRoute: "https://www.cyberport.de/apple-und-zubehoer/apple-iphone/apple/pdp/a415-18k/apple-iphone-7-32-gb-schwarz-mn8x2zd-a.html",
        expectedNewsletterlink: false
    },
    {
        input: "https://www.cyberport.de/apple-und-zubehoer/apple-iphone/apple/pdp/a415-18k/apple-iphone-7-32-gb-schwarz-mn8x2zd-a.html",
        expectedPathName: "/apple-und-zubehoer/apple-iphone/apple/pdp/a415-18k/apple-iphone-7-32-gb-schwarz-mn8x2zd-a.html",
        expectedSearchString: "",
        expectedRoute: "https://www.cyberport.de/apple-und-zubehoer/apple-iphone/apple/pdp/a415-18k/apple-iphone-7-32-gb-schwarz-mn8x2zd-a.html",
        expectedNewsletterlink: false
    }
];

/** ############### Test implementation ############### **/
links.forEach( (link, position) => {
    test(position+'. test for '+link.input, () => {
        const route = new Route(link.input);
        expect(route.getPathname()).toBe(link.expectedPathName);
        expect(route.getSearchString()).toBe(link.expectedSearchString);
        expect(route.getFullRoute()).toBe(link.expectedRoute);
    });
});



/**
 * 2. Test Suite:
 */
/** ############### Links under test ############### **/
const newsletterLinks = [
    {
        input: "https://click.mail.cyberport.de/?qs=705781632fc1fe50204205a707f837d70a047c223435fc625ac5afb77774e73025e7b2f937cda5e277c56501f2ca99bb97f97ee862dd2477a16dd1a282ba8fef",
        expectedPathName: "/",
        expectedSearchString: "?qs=705781632fc1fe50204205a707f837d70a047c223435fc625ac5afb77774e73025e7b2f937cda5e277c56501f2ca99bb97f97ee862dd2477a16dd1a282ba8fef",
        expectedRoute: "https://click.mail.cyberport.de/?qs=705781632fc1fe50204205a707f837d70a047c223435fc625ac5afb77774e73025e7b2f937cda5e277c56501f2ca99bb97f97ee862dd2477a16dd1a282ba8fef",
        expectedNewsletterlink: true
    }
];

const newsletterLinksCollection = links.concat(newsletterLinks);
/** ############### Test implementation ############### **/
newsletterLinksCollection.forEach( (linkToTest, position) => {
    test(position+'. test for '+linkToTest.input, () => {
        const route = new Route(linkToTest.input);
        expect(route.isNewsletterLink()).toBe(linkToTest.expectedNewsletterlink);
    });
});
