
import {debugLogger as log} from '../logger/log'
import {Router} from '../util/router'

class CheckoutApplePayApp {
    constructor(){
        this.liveEnvironment = true;
        this.updateMethods = null;
        this.updateMethods = window.checkoutApplePay.getUpdateMethods();
        this.isNewCheckout = false;
    }

    toggleApplePayButtonVisibility(){
        if(this.isNewCheckout){
            var $applePayButton = $('[data-js="startApplePaySession"]');
            var $applePayButtonContainer = $('[data-js="startApplePaySession"]').parent();
            if($applePayButton && !$applePayButton.hasClass("hidden")){
                $applePayButton.show();
                $applePayButtonContainer.show();
                $applePayButtonContainer.removeClass("hidden");
            }
        } else {
            var $applePayButton = $(".apple-pay-button");
            if($applePayButton && !$applePayButton.hasClass("hidden")){
                $applePayButton.show();
            }
        }   
    }

    startSession(orderObject){
        log.debug("startSession: "+JSON.stringify(orderObject));
        var self = this;
        this.applePayPaymentRequest = orderObject;
        
        ApplePay.makePaymentRequest(this.applePayPaymentRequest, 
            function(paymentResponse){
                log.debug("makePaymentRequest: payment authorized, onSuccess callback fired: "+JSON.stringify(paymentResponse));
                try {
                    var updateMethod = self.updateMethods.authorizePayment;
                    var eventDataFromPaysheet = window.checkoutApplePay.eventStringify('payment', paymentResponse);
                    window.checkoutApplePay.updateRequest(updateMethod, eventDataFromPaysheet, async function(action, result){
                        if(result!==false){
                            log.debug("makePaymentRequest AEM response for paymentAuthorization:"+action+"; result:"+JSON.stringify(result));
                            if (result.status===0) {
                                await ApplePay.completeLastTransaction(result);
                                await ApplePay.stopListeningForShippingContactSelection();
                                await ApplePay.stopListeningForShippingMethodSelection();
                                window.checkoutViewHandler.setApplePayConfirmationView();
                            }
                            else {
                                /** TODO: Maybe move out the error handling of wrong result status codes to the plugin*/
                                if(typeof(result)=== 'number'){
                                   result = {"status":result};
                                }
                                if(!result){
                                   result = {"status":500};
                                }
                                if(!result.status){
                                   result = {"status":500};
                                }
                                await ApplePay.completeLastTransaction(result);
                            }
                        } else {
                            // TODO: AJAX CALL ERROR
                            
                        } 
                    });
                } catch (err) {
                    log.debug("makePaymentRequest: handle errors for payment request");
                    log.debug(err);
                }
            }, function(errorResponse){
                // When the process of payment authorization failed on the iOS native side. This should never happen ...
                log.debug("makePaymentRequest: payment authorization failed, onError callback fired");
                log.debug(paymentResponse);
            }
         );
        
        ApplePay.onshippingmethodselected(async selectedMethod => {
            log.debug("onshippingmethodselected: iOS->JS shippingMethod selection: "+JSON.stringify(selectedMethod));
            var updateMethod = self.updateMethods.shippingMethodUpdate;
            var eventDataFromPaysheet = window.checkoutApplePay.eventStringify('shippingMethod', selectedMethod);
            window.checkoutApplePay.updateRequest(updateMethod, eventDataFromPaysheet, async function(action, result){
                if(result!==false){
                    log.debug("onshippingmethodselected: AEM response SUCCESS:"+action+"; result:"+JSON.stringify(result));
                    if(typeof(result)=== 'number'){
                       result = {"aemAjaxRequestFailureStatusCode":500};
                    }
                    if(!result || typeof(result)=== 'boolean'){
                       result = {"aemAjaxRequestFailureStatusCode":500};
                    }
                    try {
                        await ApplePay.completeShippingMethodSelection(result);
                    }
                    catch (e) {
                        
                        log.debug(e);
                    }
                } else {
                    // This should not happen: AJAX CALL ERROR
                    log.debug("onshippingmethodselected: AEM response ERROR");
                    try {
                        var result = {"aemAjaxRequestFailureStatusCode":500};
                        await ApplePay.completeShippingMethodSelection(result);
                    }
                    catch (e) {
                        log.debug("onshippingmethodselected: handle error for callBackOnShippingContact");
                        log.debug(e);
                    }
                } 
            });
        });
        
        ApplePay.onshippingcontactselected(async selectedContact => {
            log.debug("onshippingcontactselected: shippingContact selection: "+JSON.stringify(selectedContact));
            var updateMethod = self.updateMethods.shippingContact;
            log.debug("onshippingcontactselected: eventDataFromPaysheet updateMethod: "+JSON.stringify(updateMethod));
            var eventDataFromPaysheet = window.checkoutApplePay.eventStringify('shippingContact', selectedContact);
            log.debug("onshippingcontactselected: eventDataFromPaysheet shippingContact"+JSON.stringify(eventDataFromPaysheet));
            window.checkoutApplePay.updateRequest(updateMethod, eventDataFromPaysheet, async function(action, result){
                if(result!==false){
                    log.debug("onshippingcontactselected: AEM response SUCCESS: "+action+"; result:"+JSON.stringify(result));
                    if(typeof(result)=== 'number'){
                       result = {"aemAjaxRequestFailureStatusCode":500};
                    }
                    if(!result || typeof(result)=== 'boolean'){
                       result = {"aemAjaxRequestFailureStatusCode":500};
                    }
                    try {
                        await ApplePay.completeShippingContactSelection(result);
                    }
                    catch (e) {
                        log.debug("onshippingcontactselected handle error callBackOnShippingContact");
                        log.debug(e);
                    }
                } else {
                    // This should not happen: AJAX CALL ERROR
                    log.debug("onshippingmethodselected: AEM response ERROR");
                    try {
                        var result = {"aemAjaxRequestFailureStatusCode":500};
                        await ApplePay.completeShippingMethodSelection(result);
                    }
                    catch (e) {
                        log.debug("onshippingcontactselected handle error callBackOnShippingContact");
                        log.debug(e);
                    }
                }
            });
        });
    };
    
    createSession(){
        var self = this;
        log.debug("createSession start");
        if(this.isNewCheckout){
            window.checkoutApplePay.setCordovaApp();
        } else {
            window.checkoutApplePay.checkIfCordovaApp();
        }  

        window.checkoutApplePay.createSession(function(applePayPaymentRequest){
            if(applePayPaymentRequest){
                log.debug("createSession: paymentRequest from AEM received");
                applePayPaymentRequest.merchantIdentifier = 'merchant.de.ios.cyberport';
                self.startSession(applePayPaymentRequest);
            } else {
                log.debug("createSession: paymentRequest from AEM __NOT__ received");
            }
        });
    };
    
    init(){
        var self = this;
        if(window.checkoutApplePay){
            ApplePay.canMakePayments()
                .then((successMessage) => {            
                    log.debug("iOS->JS APay possible: "+JSON.stringify(successMessage));
                    self.isNewCheckout = Router.isPageCheckoutNew();
                    var $applePayButton = this.isNewCheckout ? $('[data-js="startApplePaySession"]') : $(".apple-pay-button");
                    if($applePayButton){
                       $applePayButton.on('click', function(){
                           if(!$applePayButton.hasClass("hidden")){
                               //window.animationHelper.addLoadingAnimation($applePayButton);
                                self.createSession();
                            }
                        });
                    }
                    self.toggleApplePayButtonVisibility();
                    
                    $(window).on('cp.updateCartdata', function(){
                        self.toggleApplePayButtonVisibility();
                    });
                })
                .catch((errorMessage) => {
                    log.debug("iOS->JS APay NOT possible: " + JSON.stringify(errorMessage));
                }
            );
        }
    }
}
export {CheckoutApplePayApp};
