
import {debugLogger as log} from '../logger/log'

class CheckoutApplePayApp {
    constructor(){
        this.liveEnvironment = false;
        this.updateMethods = null;
        if(this.liveEnvironment===true){
            this.updateMethods = window.checkoutApplePay.getUpdateMethods();
            
        }
        this.applePayPaymentRequest = {
            merchantIdentifier: 'merchant.de.ios.cyberport',
            countryCode: 'DE',
            currencyCode: 'EUR',
            shippingType: 'shipping',
            lineItems: [
                  {
                      label: '123 subTotal',
                      amount: 10.00,
                      type: "final"
                  }
            ],
            requiredBillingContactFields: [
                "postalAddress",
                "postalAddress"
            ],
            requiredShippingContactFields: [
                "postalAddress",
                "name",
                "email",
                "phone"
            ],
            total: {
                      label: 'fantasy Cyberport GmbH',
                      amount: 20,
                      type: "final"
            },
            shippingMethods: [
                  {
                      identifier: 'DHL',
                      label: 'fantasy Zustellung per DHL',
                      detail: 'Zustellung per DHL.',
                      amount: 5
                  },
                  {
                      identifier: 'Standard',
                      label: 'fantasy Standard',
                      detail: 'Standardzustellung Detail.',
                      amount: 10
                  },
                  {
                      identifier: 'Express',
                      label: 'fantasy Expresszustellung',
                      detail: 'Express Detail Text',
                      amount: 15
                  },
                  {
                      identifier: 'Store',
                      label: 'fantasy Abholung im Store',
                      detail: 'Store Detail Text',
                      amount: 20
                  }
              ],
            applicationData: "applicationdata123"
        };
        this.newLineItems = [{label: 'fantasy', amount: 123},{label: 'new fantasy deliveryCost', amount: 4.99}];
        this.newTotal = {label: 'fantasy Cyberport GmbH', amount: 479.99, type: 'final'};
        this.newShippingMethods = [{label: 'fantasy Standardzustellung',amount: 1,detail: 'fantasy Standardzustellung',identifier: 'Standard'}];
    }
    

    toggleApplePayButtonVisibility(){
        var $applePayButton = $(".apple-pay-button");
        if($applePayButton && !$applePayButton.hasClass("hidden")){
            $applePayButton.show();
        }
    }

    startSession(orderObject){
        console.log("startSession");
        console.log(orderObject);
        var self = this;
        if(this.liveEnvironment){
            this.applePayPaymentRequest = orderObject;
        } 
        ApplePay.makePaymentRequest(this.applePayPaymentRequest)
        .then(async (paymentResponse) => {
            console.log("The user has authorized the payment.: "+JSON.stringify(paymentResponse));
            console.log(paymentResponse);

            /* handle PaymentProviderAuthorization and Processing*/
            try {
                if(this.liveEnvironment){
                    var updateMethod = this.updateMethods.authorizePayment;
                    var eventDataFromPaysheet = window.checkoutApplePay.eventStringify('payment', paymentResponse);
                    window.checkoutApplePay.updateRequest(updateMethod, eventDataFromPaysheet, async function(action, result){
                        if(result!==false){
                            console.log("call paymentAuthorized action:"+action+"; result:"+JSON.stringify(result));
                            if (result.status===0) {
                                await ApplePay.completeLastTransaction(result);
                                await ApplePay.stopListeningForShippingContactSelection();
                                await ApplePay.stopListeningForShippingMethodSelection();
                                window.checkoutViewHandler.setApplePayConfirmationView();
                            }
                            else {
                                /** TODO: Maybe move out the error handling of wrong result status codes to the plugin*/
                                if(typeof(result)=== 'number'){
                                   result = {"status":result};
                                }
                                if(!result){
                                   result = {"status":9999};
                                }
                                if(!result.status){
                                   result = {"status":9999};
                                }
                                await ApplePay.completeLastTransaction(result);
                                await ApplePay.stopListeningForShippingContactSelection();
                                await ApplePay.stopListeningForShippingMethodSelection();
                            }
                        } else if(result===false){
                            // TODO: AJAX CALL SUCCESS, status error
                        } else {
                            // TODO: AJAX CALL ERROR
                        } 
                    });
                } else {
                    var successStatus = false;
                    if (successStatus) {
                        await ApplePay.completeLastTransaction({"status": 0});
                        await ApplePay.stopListeningForShippingContactSelection();
                        await ApplePay.stopListeningForShippingMethodSelection();
                    }
                    else {
                        var err = {
                            "status" : 1,
                            "errors" : [
                                {
                                    "code" : "billingContactInvalid",
                                    "contactField" : "postalAddress",
                                    "message" : "Invalid name"
                                }
                            ]
                        };
                        await ApplePay.completeLastTransaction(err);
                        await ApplePay.stopListeningForShippingContactSelection();
                        await ApplePay.stopListeningForShippingMethodSelection();
                    }
                }
            }
            catch (err) {
                console.log("handle payment request or transaction errors");
                console.log(err);
            }
        })
        .catch((e) => {
            console.log("Failed to open the Apple Pay sheet, or the user cancelled the payment.");
            console.log(e);
        });
        ApplePay.onshippingmethodselected(async selectedMethod => {
            console.log("shippingMethod selection: "+JSON.stringify(selectedMethod));
            if(self.liveEnvironment){
                var updateMethod = self.updateMethods.shippingMethodUpdate;
                var eventDataFromPaysheet = window.checkoutApplePay.eventStringify('shippingMethod', selectedMethod);
                console.log("eventDataFromPaysheet: for onshippingmethodselected"+JSON.stringify(eventDataFromPaysheet));
                window.checkoutApplePay.updateRequest(updateMethod, eventDataFromPaysheet, async function(action, result){
                    if(result!==false){
                        console.log("call onshippingmethodselected action:"+action+"; result:"+JSON.stringify(result));
                        if(typeof(result)=== 'number'){
                           result = {"errors":result};
                        }
                        if(!result || typeof(result)=== 'boolean'){
                           result = {"errors":9999};
                        }
                        try {
                            await ApplePay.completeShippingMethodSelection(result);
                        }
                        catch (e) {
                            console.log("handle error callBackOnShippingContact");
                            console.log(e);
                        }
                    } else {
                        // TODO: AJAX CALL ERROR
                        try {
                            var result = {"errors":9999};
                            await ApplePay.completeShippingMethodSelection(result);
                        }
                        catch (e) {
                            console.log("handle error callBackOnShippingContact");
                            console.log(e);
                        }
                    } 
                });
            } else {
                var newTotal = {label: 'Updated Cyberport GmbH Total', amount: 479.99, type: 'final'};
                try {
                    await ApplePay.completeShippingMethodSelection({newTotal});
                }
                catch (e) {
                    console.log("handle error if shipping method selection couldn't complete for some reason");
                    console.log(e);
                }
            }     
        });
        
        ApplePay.onshippingcontactselected(async selectedContact => {
            console.log("shippingContact selection: "+JSON.stringify(selectedContact));
            if(self.liveEnvironment){
                var updateMethod = self.updateMethods.shippingContact;
                console.log("eventDataFromPaysheet updateMethod: "+JSON.stringify(updateMethod));
                var eventDataFromPaysheet = window.checkoutApplePay.eventStringify('shippingContact', selectedContact);
                console.log("eventDataFromPaysheet shippingContact"+JSON.stringify(eventDataFromPaysheet));
                window.checkoutApplePay.updateRequest(updateMethod, eventDataFromPaysheet, async function(action, result){
                    if(result!==false){
                        console.log("callBackOnShippingContact action:"+action+"; result:"+JSON.stringify(result));
                        if(typeof(result)=== 'number'){
                           result = {"errors":result};
                        }
                        if(!result || typeof(result)=== 'boolean'){
                           result = {"errors":9999};
                        }
                        try {
                            await ApplePay.completeShippingContactSelection(result);
                        }
                        catch (e) {
                            console.log("handle error callBackOnShippingContact");
                            console.log(e);
                        }
                    } else {
                        // TODO: AJAX CALL ERROR
                        try {
                            var result = {"errors":9999};
                            await ApplePay.completeShippingMethodSelection(result);
                        }
                        catch (e) {
                            console.log("handle error callBackOnShippingContact");
                            console.log(e);
                        }
                    }
                });
            } else {
                try {
                    var newTotal = {label: 'Updated Cyberport GmbH Total', amount: 479.99, type: 'final'};
                    await ApplePay.completeShippingContactSelection({newTotal});
                }
                catch (e) {
                    console.log("handle error if shipping contact selection couldn't complete: "+JSON.stringify(e));
                }
            }
            
        });
    };
    
    createSession(){
        var self = this;
        console.log("createSession start");
        window.checkoutApplePay.checkIfCordovaApp();
        console.log("createSession get applePayPaymentRequest");
        window.checkoutApplePay.createSession(function(applePayPaymentRequest){
            if(applePayPaymentRequest){
                console.log("createSession paymentRequest received");
                applePayPaymentRequest.merchantIdentifier = 'merchant.de.ios.cyberport';
                self.startSession(applePayPaymentRequest);
            } else {
                console.log("apay not possible: No applePayPaymentRequest retrieved");
            }
        });
    };
    
    init(){
        var self = this;
        if(window.checkoutApplePay){
            ApplePay.canMakePayments()
                .then((successMessage) => {
                    console.log("apay possible message: "+JSON.stringify(successMessage));
                    var $applePayButton = $(".apple-pay-button");
                    if($applePayButton){
                       $applePayButton.on('click', function(){
                           if(!$applePayButton.hasClass("hidden")){
                                self.createSession();
                            }
                        });
                    }
                    if(this.liveEnvironment){
                        console.log("liveEnvironment");
                        self.toggleApplePayButtonVisibility();
                        console.log("try to createSession");
                        self.createSession();
                        
                    } else {
                        console.log("dev Environment");
                        self.startSession(); 
                    }
                    $(window).on('cp.updateCartdata', function(){
                        self.toggleApplePayButtonVisibility();
                    });
                })
                .catch((errorMessage) => {
                    console.log("apay not possible catch message:" + JSON.stringify(errorMessage));
                }
            );
        }
    }
}
export {CheckoutApplePayApp};
