import {debugLogger as log} from '../logger/log';
import DeviceDetails from "./deviceDetails";
import {Dialogs} from "./dialogs";
import CountryHandler from "./countryHandler";
import AdjustHandler from "./adjustHandler";
import Constants from "../constants";

/**
 * Function allows the barcodescanner to be shown to scan barcodes.
 * User is then redirected to the search page, including the barcode as search param.
 * @type {{triggerBarcodeScannerEvent: triggerBarcodeScannerEvent}}
 */
var BarcodeScanner = (function () {

    /**
     * Used to display barcodescanner icon and binding of triggerBarcodeScannerEvent()
     */
    function initBarcodeScanner() {
        var scannerIcon = $('#barcodescanner-button');
        if (scannerIcon.length === 1) {

            // make barcode scanner icon visible
            scannerIcon.removeClass('showInApp');

            // bind barcode scanner click event
            scannerIcon.click(function (event) {
                //remove default click event of button
                event.preventDefault();
                BarcodeScanner.triggerBarcodeScannerEvent();
            });
        }
    }

    /**
     * Used to open the barcodescanner
     */
    function triggerBarcodeScannerEvent() {
        window.ADB.trackTimedActionStart("barcodeScanner");
        AdjustHandler.trackBarcodescannerEvent();
        var startBarcodeScanTime = new Date();
        window.cordova.plugins.barcodeScanner.scan(
            function (result) {
                var timeDiffBarcodeScanTime = ((new Date()  - startBarcodeScanTime )/1000);
                window.ADB.trackAction("barcodeScanner", {"duration":timeDiffBarcodeScanTime});
                window.ADB.trackTimedActionEnd("barcodeScanner");
                log.debug("timeDiffBarcodeScanTime "+timeDiffBarcodeScanTime);
                console.log("format: "+result.format);
                if (!result.cancelled) {
                    if(result.format!=="CODE_128"){
                        var url = CountryHandler.getBaseUrlForLocale(DeviceDetails.readCookie("selected_shop")) + Constants.shopUrlSearch + result.text;
                        window.ADB.trackAction("barcodeScanner", {"landingPage":url});
                        window.ADB.trackAction("barcodeScanner", {"barCodeType":"EAN_13"});
                        window.location.href = url;
                    } else {
                        /*
                        Feature toggled off, as bestelldetails.html link is not yet approved. (login problems)
                        var url = getBaseUrlForLocale(DeviceDetails.readCookie("selected_shop")) + "de/tools/my-account/meine-bestellungen/bestelldetails.html?id=" + result.text;
                        window.ADB.trackAction("barcodeScanner", {"landingPage":url});
                        window.ADB.trackAction("barcodeScanner", {"barCodeType":"CODE_128"});
                        if(url.indexOf("&from") === -1){
                            url = url+"&from=2018-02-01"
                        }
                        if(url.indexOf("&to") === -1){
                            var today = new Date();
                            var dd = String(today.getDate()).padStart(2, '0');
                            var mm = String(today.getMonth() + 1).padStart(2, '0'); //January is 0!
                            var yyyy = today.getFullYear();
                            today = yyyy + '-' + mm + '-' + dd;
                            url = url+"&to="+today;
                        }
                        window.location.href = url;
                        */
                    }
                } else {
                    window.ADB.trackAction("barcodeScanner", {"landingPage":"none: abbruch"});
                }
            },
            function (error) {
                if(error==="Illegal access" || DeviceDetails.isIos()){
                    if (window.cordova && window.cordova.plugins.settings) {
                        var barcodeScannerPermissionCallback = function (buttonIndex) {
                            if (buttonIndex === 2) {
                                if(DeviceDetails.isAndroid()){
                                    window.cordova.plugins.settings.open("application_details", function() {
                                        },
                                        function () {
                                            log.debug('failed to open settings');
                                        }
                                    );
                                } else {
                                    window.cordova.plugins.settings.open("settings", function() {
                                        },
                                        function () {
                                            log.debug('failed to open settings');
                                        }
                                    );
                                }
                            }
                        }
                        var timeDiffBarcodeScanTime = Math.round(((new Date()  - startBarcodeScanTime )/1000) % 60);
                        window.ADB.trackAction("barcodeScanner", {"landingPage":"none: keine Kameraberechtigung"});
                        window.ADB.trackAction("barcodeScanner", {"duration":timeDiffBarcodeScanTime})
                        window.ADB.trackTimedActionEnd("barcodeScanner");

                        navigator.notification.confirm(
                            'Cyberport hat keinen Zugriff auf Ihre Kamera. Um Zugriff zu erlauben, Geräte-Einstellungen öffnen und unter Cyberport die Verwendung der Kamera aktivieren.',  // message
                            barcodeScannerPermissionCallback,            // callback to invoke
                            'Scan nicht möglich',                       // title
                            ['Abbrechen','Einstellungen']             // buttonLabels
                        );
                    } else {
                        var timeDiffBarcodeScanTime = Math.round(((new Date()  - startBarcodeScanTime )/1000) % 60);
                        window.ADB.trackTimedActionEnd("barcodeScanner");
                        window.ADB.trackAction("barcodeScanner", {"landingPage":"none: keine Kameraberechtigung"});
                        window.ADB.trackAction("barcodeScanner", {"duration":timeDiffBarcodeScanTime});
                        Dialogs.showNotificationAlert('Scan nicht möglich', 'Cyberport hat keinen Zugriff auf Ihre Kamera. Um Zugriff zu erlauben, Geräte-Einstellungen öffnen und unter Cyberport die Verwendung der Kamera aktivieren', 'OK');
                    }
                } else {
                    var timeDiffBarcodeScanTime = Math.round(((new Date()  - startBarcodeScanTime )/1000) % 60);
                    window.ADB.trackTimedActionEnd("barcodeScanner");
                    window.ADB.trackAction("barcodeScanner", {"landingPage":"none: keine Kameraberechtigung"});
                    window.ADB.trackAction("barcodeScanner", {"duration":timeDiffBarcodeScanTime});
                    Dialogs.showNotificationAlert('Scan nicht möglich', 'Leider hat der Scan nicht funktioniert.', 'OK');
                }
                log.error('Barcodescan not successful. Error -> ' + JSON.stringify(error));
            },
            {
                preferFrontCamera : false, // iOS and Android
                showFlipCameraButton : false, // iOS and Android
                showTorchButton : true, // iOS and Android
                torchOn: false, // Android, launch with the torch switched on (if available)
                prompt : 'Platzieren Sie den Barcode in den sichtbaren Bereich', // Android
                resultDisplayDuration: 0, // Android, display scanned text for X ms. 0 suppresses it entirely, default 1500
                formats : 'EAN_8,EAN_13,CODE_128', // default: all but PDF_417 and RSS_EXPANDED
                orientation : 'portrait', // Android only (portrait|landscape), default unset so it rotates with the device
                disableAnimations : false, // iOS
                disableSuccessBeep: true // iOS
            }
        );
    }

    // ++++++++++++++++++++++++++++++++ Public methods ++++++++++++++++++++++++++++++++
    return {
        triggerBarcodeScannerEvent: triggerBarcodeScannerEvent,
        initBarcodeScanner: initBarcodeScanner
    };
})();
export {BarcodeScanner};
