import {debugLogger as log} from "../logger/log";

/**
 * The CookieHandler can create, read and erase cookies and ist mostly used to set the locale (DE/AT of the user into selected_shop=DE/AT
 */
export default class CookieHandler{
    /**
     *
     * @param name
     * @param value
     * @param days
     */
    static createCookie(name, value, days) {
        let expires;
        let date;
        if(days){
            date = new Date();
            date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
            expires = '; expires=' + date.toUTCString();
        }
        else {
            expires = '';
        }
        document.cookie = name + '=' + value + expires + '; path=/';
        log.debug("Cookie created: "+name+"; value: "+value);
    }

    /**
     * Sets a cookie containing the selected shop for analytics purposes
     * @param settings
     */
    static handleCookieForLocalizedShop(settings) {
        var cookieName = 'selected_shop';
        var cookieExpiration = 1000; // days
        if (CookieHandler.readCookie(cookieName) === null) {
            CookieHandler.createCookie(cookieName, settings.selectedShop.toLowerCase(), cookieExpiration);
        } else {
            CookieHandler.eraseCookie(cookieName);
            CookieHandler.createCookie(cookieName, settings.selectedShop.toLowerCase(), cookieExpiration);
        }
    }

    /**
     *
     * @param name
     * @returns {*}
     */
    static readCookie(name) {
        var nameEQ = name + '=';
        var ca = document.cookie.split(';');
        for(var i = 0; i < ca.length; i++) {
            var c = ca[i];
            while (c.charAt(0) === ' ') {
                c = c.substring(1, c.length);
            }
            if (c.indexOf(nameEQ) === 0) {
                log.debug("Cookie found: name");
                return c.substring(nameEQ.length,c.length);
            }
        }
        log.debug("Cookie not found: "+name);
        return null;
    }

    /**
     *
     * @param name
     */
    static eraseCookie(name) {
        log.debug("Cookie erased: "+name);
        CookieHandler.createCookie(name, '', -1);
    }

}