import {Deeplink} from "./deeplink";

/** ############### Links under test ############### **/
var testUrls = [
    {
        input: "https://cyberport.de",
        expected: "https://app.cyberport.de/content/webshop30_de/de.html"
    },
    {
        input: "https://cyberport.de?DEEP=1H62-020",
        expected: "https://app.cyberport.de/content/webshop30_de/de.html?DEEP=1H62-020"
    },
    {
        input: "https://app.cyberport.de/content/webshop30_de/de.html",
        expected: "https://app.cyberport.de/content/webshop30_de/de.html"
    },
    {
        input: "https://www.cyberport.de/apple-und-zubehoer.html",
        expected: "https://app.cyberport.de/content/webshop30_de/de/apple-und-zubehoer.html"
    },
    {
        input: "https://www.cyberport.de/?APID=7&wt_cc2=DOI-NL_2009-1",
        expected: "https://app.cyberport.de/content/webshop30_de/de.html?APID=7&wt_cc2=DOI-NL_2009-1"
    },
    {
        input: "https://www.cyberport.de/notebook-und-tablet/tablets/apple/pdp/1h62-03q/apple-ipad-10-2-7th-generation-wi-fi-32-gb-space-grau-mw742fd-a.html",
        expected: "https://app.cyberport.de/content/webshop30_de/de/notebook-und-tablet/tablets/apple/pdp/1h62-03q/apple-ipad-10-2-7th-generation-wi-fi-32-gb-space-grau-mw742fd-a.html"
    },
    {
        input: "https://www.cyberport.de/notebook-und-tablet/tablets/apple.pdp/1h62-03q/apple-ipad-10-2-7th-generation-wi-fi-32-gb-space-grau-mw742fd-a.html",
        expected: "https://app.cyberport.de/content/webshop30_de/de/notebook-und-tablet/tablets/apple/pdp/1h62-03q/apple-ipad-10-2-7th-generation-wi-fi-32-gb-space-grau-mw742fd-a.html"
    },
    {
        input: "https://www.cyberport.de/tools/search-results.html?autosuggest=false&q=batterie",
        expected: "https://app.cyberport.de/content/webshop30_de/de/tools/search-results.html?autosuggest=false&q=batterie"
    },
    {
        input: "https://www.cyberport.de/tools/wishlist.html?%5B%226136-13L%22%2C%226136-163%22%5D&wt_cc2=mobile_sharing-android-lo",
        expected: "https://app.cyberport.de/content/webshop30_de/de/tools/wishlist.html?%5B%226136-13L%22%2C%226136-163%22%5D&wt_cc2=mobile_sharing-android-lo"
    },
    {
        input: "https://www.cyberport.de/service/rechtliches/impressum.html?",
        expected: "https://app.cyberport.de/content/webshop30_de/de/service/rechtliches/impressum.html"
    }
];

/** ############### Prepare Test Setup ############### **/
Deeplink.setSettings({
    selectedShop : 'de',
    autoLogin: true,
    fingerprintLogin: false,
    fingerprintLoginDecision: '',
    credentials : {
        username: '',
        password: '',
        valid: false
    },
    lastStartup: 0,
    autoLoginTimeout: 30,
    preventAutoLoginForLoggedOutUser: false,
    countForSessionTimeoutMessage: 0,            // Session Timeout Message is shown, when value = 1
    showDialogAskForFingerprintDecision: true
});

function createEventData(url){
    var eventData = {};
    eventData.url = url;
    return eventData;
}

/** ############### Test implementation ############### **/
testUrls.forEach( (urlToTest, position) => {
    test(position+'. test for '+urlToTest.input, () => {
        var eventData = createEventData(urlToTest.input);
        var outputtedUrl = Deeplink.transformInputUrlToRedirectableUrl(eventData.url);
        expect(outputtedUrl).toBe(urlToTest.expected);
    });
});
