import {debugLogger as log} from '../logger/log';


export default class DeviceDetails {
    /**
     * @returns {String} ios, android or other
     */
    static getMobilePlatform() {
        if (!!navigator.platform && /iPad|iPhone|MacIntel|iPod/.test(navigator.platform)) {
            return 'ios';
        } else if (navigator.userAgent.toLowerCase().indexOf('android') > -1) {
            return 'android';
        } else {
            return 'other';
        }
    }
    /**
     * @returns {boolean}
     */
    static isAndroid(){
        return 'android' === this.getMobilePlatform();
    }
    /**
     * @returns {boolean}
     */
    static isIos() {
        return 'ios' === this.getMobilePlatform();
    }
    /**
     * @returns {boolean}
     */
    static isIpad(){
        return navigator.userAgent.match(/iPad/i) != null;
    }

    /**
     * Detects via viewport width whether the device is a tablet or not.
     * @returns {boolean}
     */
    static isTablet(){
        var viewportWidth = Math.max(document.documentElement.clientWidth, window.innerWidth || 0);
        if(viewportWidth>767){
            return true;
        } else {
            return false;
        }
    }
    /**
     * Detects via viewport width/height whether the device is a iphone x.
     * @returns {boolean}
     */
    static isIphoneX(){
        var ratio = window.devicePixelRatio || 1;
        var screen = {
            width : window.screen.width * ratio,
            height : window.screen.height * ratio
        };
        if (this.isIos() && screen.width == 1125 && screen.height === 2436) {
            return true;
        } else {
            return false;
        }
    }

    /**
     *
     * @param name
     * @returns {*}
     */
    static readCookie(name) {
        var nameEQ = name + '=';
        var ca = document.cookie.split(';');
        for(var i = 0; i < ca.length; i++) {
            var c = ca[i];
            while (c.charAt(0) === ' ') {
                c = c.substring(1, c.length);
            }
            if (c.indexOf(nameEQ) === 0) {
                return c.substring(nameEQ.length,c.length);
            }
        }
        return null;
    }
}
