import {debugLogger as log} from '../logger/log';
import DeviceDetails from "./deviceDetails";

/**
 * This function is used to intercept clicks on anchors with href to pdf datasheets, as the webviews
 * may not have a PDF renderer included and would not show the PDF.
 * Intercepting means, instead of opening the PDF link in the webview, the PDF is downloaded and opened in a native PDF viewer.
 */

function energyEfficiencyPdfToBrowser(){
    var pdflinks = $("[href*='datasheet']");
    for (var i=0; i < pdflinks.length; i++) {
        var link = pdflinks[i];
        log.debug("Binding for: "+link.href);
        (function(link){
            if(DeviceDetails.isIos() || DeviceDetails.isIpad()){
                link.onclick = function(e){
                    e.preventDefault();
                    log.debug("energyefficiency: ios click:"+link.href);
                    handleIos(e,link)
                }
            } else {
                link.onclick = function(e){
                    e.preventDefault();
                    log.debug("energyefficiency: android click: "+link.href);
                    handleAndroid(e,link)
                }
            };
        }(link))
    }
}

function handleIos(event,link){
    event.preventDefault();
    log.debug("energyefficiency: ios");
    navigator.notification.confirm(
        "",
        function(buttonIndex){
            switch(buttonIndex){
                case 1:
                    break;
                case 2:
                    cordova.InAppBrowser.open(link.href, '_system');
                    break;
                default:
                    break;
            }
        },
        "Inhalt im Browser öffnen?",
        ['Abbrechen','OK']);
}

function handleAndroid(event,link){
    log.debug("energyefficiency: android");
    window.cordova.downloadUrl = link.href;
    var downloadUrl = link.href;
    var filename = downloadUrl;
    filename = filename.substring(filename.lastIndexOf('/')+1);
    filename = filename.replace("?","_");
    filename = filename.replace(/\&/g,"_");
    filename = filename.replace(/\=/g,"_");
    filename = filename.replace(".pdf","");
    filename = filename+".pdf";
    window.requestFileSystem(window.TEMPORARY, 5 * 1024 * 1024, function (fs) {
            log.debug('file system open: ' + fs.name);
            downloadPdfFile(fs.root, downloadUrl, filename);
        }, function(e) {
            log.debug("onerrorLoadFs: Failed file write: " + e.toString());
            onErrorOpenBrowser()
        }
    );
}




function downloadPdfFile(dirEntry, downloadUrl, filename) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', downloadUrl, true);
    xhr.responseType = 'blob';
    xhr.onload = function() {
        if (this.status == 200) {
            var fileDataAsBlob = new Blob([this.response], { type: 'application/pdf' });
            saveFileToDevice(dirEntry, fileDataAsBlob, filename);
        } else {
            log.debug("xhr.onload status != 200");
            onErrorOpenBrowser()
        }
    };
    xhr.send();
}
function saveFileToDevice(dirEntry, fileDataAsBlob, fileName) {
    dirEntry.getFile(fileName, { create: true, exclusive: false }, function (fileEntry) {
            writeFile(fileEntry, fileDataAsBlob);
        }, function(e) {
            log.debug("onErrorSaveFile: Failed file write: " + e.toString());
            onErrorOpenBrowser()
        }
    );
}
function writeFile(fileEntry, dataObj, isAppend) {
    fileEntry.createWriter(function (fileWriter) {
        fileWriter.onwriteend = function() {
            log.debug("Successful file write...");
            if (dataObj.type == "application/pdf") {
                readPdfFile(fileEntry);
            }
        };
        fileWriter.onerror = function(e) {
            log.debug("Failed file write: " + e.toString());
            onErrorOpenBrowser()
        };
        fileWriter.write(dataObj);
    });
}
function readPdfFile(fileEntry) {
    fileEntry.file(function (file) {
        log.debug("file123");
        log.debug(JSON.stringify(file));
        resolveLocalFileSystemURL(file.localURL, function (entry) {
            var nativePath = entry.toURL();
            log.debug("nativePath");
            log.debug(nativePath);
            pushPdfToPdfViewer(nativePath);
        });
    });
}

function pushPdfToPdfViewer(filePath){
    cordova.plugins.fileOpener2.open(
        filePath,
        'application/pdf',
        {
            error, success
        }
    );

    function success(e) {
        console.log('Success');
    }

    function error(code) {
        if (code === 1) {
            console.log('No file handler found');
        } else {
            console.log('Undefined error');
        }
        onErrorOpenBrowser()
    }


}

function onErrorOpenBrowser(){
    cordova.InAppBrowser.open(window.cordova.downloadUrl, '_system');
}

export {energyEfficiencyPdfToBrowser};
