import {debugLogger as log} from '../logger/log';

/**
 * Intercepts clicks on anchors with href=*.pdf, downloads the PDF content and opens the
 * PDF in the native share dialog.
 */
function initPdfShare(){
    var pdflinks = $("[href*='.pdf']");
    for (var i=0; i < pdflinks.length; i++) {
        var link = pdflinks[i];
        link.onclick = function(e){
            e.preventDefault();
            handlePdfAnchorOnClick(link.href);
        };
    }
}

function handlePdfAnchorOnClick(downloadUrl){
    if(downloadUrl){
        var filename = downloadUrl;
        filename = filename.substring(filename.lastIndexOf('/')+1);
        filename = filename.replace("?","_");
        filename = filename.replace(/\&/g,"_");
        filename = filename.replace(/\=/g,"_");
        filename = filename.replace(".pdf","");
        filename = filename+".pdf";
        window.requestFileSystem(window.TEMPORARY, 5 * 1024 * 1024, function (fs) {
                log.debug('file system open: ' + fs.name);
                downloadPdfFile(fs.root, downloadUrl, filename);
            }, function(e) {
                log.debug("onerrorLoadFs: Failed file write: " + e.toString());
            }
        );
    }
}

function downloadPdfFile(dirEntry, downloadUrl, filename) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', downloadUrl, true);
    xhr.responseType = 'blob';
    xhr.onload = function() {
        if (this.status == 200) {
            var fileDataAsBlob = new Blob([this.response], { type: 'application/pdf' });
            saveFileToDevice(dirEntry, fileDataAsBlob, filename);
        } else {
            log.debug("xhr.onload status != 200");
        }
    };
    xhr.send();
}
function saveFileToDevice(dirEntry, fileDataAsBlob, fileName) {
    dirEntry.getFile(fileName, { create: true, exclusive: false }, function (fileEntry) {
            writeFile(fileEntry, fileDataAsBlob);
        }, function(e) {
            log.debug("onErrorSaveFile: Failed file write: " + e.toString());
        }
    );
}
function writeFile(fileEntry, dataObj, isAppend) {
    fileEntry.createWriter(function (fileWriter) {
        fileWriter.onwriteend = function() {
            log.debug("Successful file write...");
            if (dataObj.type == "application/pdf") {
                readPdfFile(fileEntry);
            }
        };
        fileWriter.onerror = function(e) {
            log.debug("Failed file write: " + e.toString());
        };
        fileWriter.write(dataObj);
    });
}
function readPdfFile(fileEntry) {
    fileEntry.file(function (file) {
            log.debug("file123");
            log.debug(JSON.stringify(file));
            resolveLocalFileSystemURL(file.localURL, function (entry) {
                var nativePath = entry.toURL();
                log.debug("nativePath");
                log.debug(nativePath);
                pushPdfToShareDialogByPath(nativePath);
            });
    });
}
function pushPdfToShareDialogByPath(filePath){
    var options = {
        files: [filePath]
    };

    var onSuccess = function(result) {
        log.debug("Share completed? " + result.completed); // On Android apps mostly return false even while it's true
        log.debug("Shared to app: " + result.app); // On Android result.app since plugin version 5.4.0 this is no longer empty. On iOS it's empty when sharing is cancelled (result.completed=false)
    };

    var onError = function(msg) {
        log.debug("Sharing failed with message: " + msg);
    };

    window.plugins.socialsharing.shareWithOptions(options, onSuccess, onError);
}

export {initPdfShare};
