import {debugLogger as log} from '../logger/log';

/**
 * Intercepts clicks on the product share dialog with href="mailto:...".
 * Such links might not be opened in the webview/mail app correctly, so they are
 * forwarded to the native share dialog.
 * @type {{_buildDeeplink: (function(*, *=, *, *): string), _openNativeShareDialog: openNativeShareDialog, handleClick: handleClick}}
 */
var ProductsToShareDialog = (function () {

    function handleClick(event, link){
        console.log("handle productsToShareDialog");
        console.log(event);
        console.log(link);
        var whitelist = [
            "https://cyberport",
            "https://www.cyberport",
            "https://app.cyberport",
            "https://www.app.cyberport",
            "https://aem-app-uat.cyberport",
            "https://aem-app-qa.cyberport",
            "https://aem-uat.cyberport",
            "https://aem-qa.cyberport"
        ];
        var link = link;
        if(link.indexOf("mailto:")>-1){
            for(var i = 0; i<whitelist.length;i++){
                log.debug("check for: "+element);
                var element = whitelist[i];
                if(link.indexOf(element)>-1){
                    log.debug("event.preventDefault for: "+element);
                    event.preventDefault();
                    var mailtoLink = link;
                    // get positions
                    var subjectStartPosition = mailtoLink.indexOf("subject=")+8;
                    var bodyStartPosition = mailtoLink.indexOf("&body=")+6;

                    // get subject
                    var subject = mailtoLink.slice(subjectStartPosition, bodyStartPosition-6);

                    // get url from body
                    var body = mailtoLink.slice(bodyStartPosition, mailtoLink.length);

                    // Remove trailing whitespace / %20
                    if(body.indexOf("%20")==0){
                        body = body.substring(3);
                    }

                    var reg = new RegExp('(https[^\"]+)');
                    var matchedUrls = body.match(reg);

                    // add track parameter
                    if(matchedUrls){
                        var oldUrlWithoutTracking = matchedUrls[0];
                        var newUrlWithTracking = buildDeeplink(oldUrlWithoutTracking,window.selectedShop,window.mobilePlatform,window.senderLoginStatus);
                        if(newUrlWithTracking){
                            body = body.replace(oldUrlWithoutTracking, newUrlWithTracking);
                            var options = {
                                chooserTitle: "Bitte wählen Sie eine App zum Teilen des Links"
                            };

                            // str = "Apple%20iPhone%2011%20128%20GB%20Gr%C3%BCn%20MWM62ZD/A%20(42,5%22)"
                            // str = "DELL%20UltraSharp%20U2415%2061cm%20(24%22)%20WUXGA%20Profi-Monitor%20HDMI/DP%2099%sRGB%206bit+FRC"
                            subject = subject.replace("99%","99%25");
                            subject = decodeURIComponent(subject)+" ";
                            body = body;
                            if($(event.target).hasClass("sendList")){
                                if(mobilePlatform=="ios"){
                                    options.subject = subject;
                                    options.message = body;
                                } else {
                                    options.subject = subject;
                                    options.message = body;
                                }
                            } else {
                                if(mobilePlatform=="ios"){
                                    options.subject = subject;
                                    options.message = "Entdeckt bei Cyberport: "+subject+" "+body;
                                } else {
                                    options.subject = " ";
                                    options.message = "Entdeckt bei Cyberport: "+subject+" "+body;
                                }
                            }
                            log.debug("share options:"+JSON.stringify(options));
                            openNativeShareDialog(options);
                        } else {
                            onError("SHARE PROCESSING: ERROR: newUrlWithTracking empty");
                        }
                    } else {
                        onError("SHARE PROCESSING: ERROR: No matches found");
                    }
                    break;
                }
            }
        }
    }

    function buildDeeplink(incomingUrl,selectedShop,mobilePlatform,senderLoginStatus) {
        var url = incomingUrl+ "&wt_cc2=mobile_sharing-" + mobilePlatform + "-" + senderLoginStatus;
        if (selectedShop) {
            if (selectedShop === "de") {
                url = url.replace(".at", ".de");
            } else {
                url = url.replace(".de", ".at");
            }
        } else {
            if (window.location.host.indexOf(".at") !== -1) {
                url = url.replace(".de", ".at");
            }
        }
        var subdomains = ["aem-qa.", "aem-app-qa.","aem-stg.","aem-app-stg.","aem-uat.","aem-app-uat.","app."];
        for(var subPosition = 0; subPosition<subdomains.length;subPosition++){
            url = url.replace(subdomains[subPosition],"");
        }
        return url;
    }
    var onSuccess = function(result) {
        log.debug("SHARE PROCESSING: social sharing onSuccess msg: "+result);
    };

    var onError = function(msg) {
        log.debug("SHARE PROCESSING: social sharing onError msg: "+msg);
    };

    function openNativeShareDialog (options){
        window.plugins.socialsharing.shareWithOptions(options, onSuccess, onError);
    }



    // ++++++++++++++++++++++++++++++++ Public methods ++++++++++++++++++++++++++++++++
    return {
        handleClick,
        _buildDeeplink : buildDeeplink,
        _openNativeShareDialog : openNativeShareDialog
    };
})();
export {ProductsToShareDialog};
