import CookieHandler from "./cookieHandler";
import Constants from "../constants";

/**
 * The router can be used to determine on which page the user is or to receive
 * specific URLs, like the baseurl.
 */
class Router{
    /**
     * @param locale
     * @returns {string}
     */
    static getBaseUrlForLocale(locale) {
        let baseUrl = window.location.protocol + '//' + window.location.host + '/content/webshop30_';
        if (locale && locale.toLowerCase() === 'at'){
            baseUrl = baseUrl + 'at/';
        } else {
            baseUrl = baseUrl + 'de/';
        }
        return baseUrl;
    }

    /**
     * @returns {string}
     */
    static getBaseUrlWithoutCountryPath() {
        let baseUrl = window.location.protocol + '//' + window.location.host;
        return baseUrl;
    }

    /**
     * Checks if current page is check out page
     * @returns {boolean}
     */
    static isPageCheckout(){
        let currentUrl = window.location.href;
        return (currentUrl.indexOf('/de/tools/checkout.html') > -1); // If > -1: Page is checkout.html
    }

    /**
     * Checks if current page is check out page
     * @returns {boolean}
     */
    static isPageCheckoutNew(){
        let currentUrl = window.location.href;
        return (currentUrl.indexOf('/de/checkout.html') > -1) && window.dataLayer.page.pageInfo.pageType==="checkoutpage2";
    }

    /**
     * Checks if current page is check out page
     * @returns {boolean}
     */
    static isPageCheckoutAccount(){
        let currentUrl = window.location.href;
        return (currentUrl.indexOf('/checkout.account.html') > -1); // If > -1: Page is checkout.account.html
    }

    static isMeineBestellungenPage (){
        let currentUrl = window.location.href;
        return (currentUrl.indexOf("meine-bestellungen") !== -1 ? true : false ) //If > -1: Page is meine-bestellungen
    }

    static isLogoutPage (){
        let currentUrl = window.location.href;
        return (currentUrl.indexOf("logout.html") !== -1 ? true : false );
    }

    /**
     *
     * @returns {boolean}
     */
    static isShopHomepage(){
        let currentUrl = window.location.href;
        return (currentUrl.indexOf('/' + Constants.shopUrlHome) > -1); // If > -1: Page is app.html
    }

    /**
     * Checks if current page is app landingpage by url
     * @param {string} currentUrl
     * @returns {boolean}
     */
    static isAppLandingPage(currentUrl){
        return (currentUrl.indexOf('/app.html') > -1); // If > -1: Page is app.html
    }
    /**
     * Checks if current page is app settings page by body class
     * @returns {boolean}
     */
    static isAppSettingsPage(){
        if ($("body").hasClass(Constants.bodyClassAppSettings)){
            return true;
        } else {
            return false;
        }
    }

    /**
     *
     * @returns {string}
     */
    static getBaseUrl() {
        return Router.getBaseUrlForLocale(CookieHandler.readCookie('selected_shop'));
    }

    static isOrderConfirmationPageNewCheckout() {
        const currentUrl = window.location.href;
        return (currentUrl.indexOf('checkout/confirmation.html') > -1);
    }
}

export {Router};
