import {debugLogger as log} from '../logger/log';
import DeviceDetails from "./deviceDetails";

/**
 * UserDetails class is used to get/set user details, like the settings, login status.
 */
export default class UserDetails {
    /**
     * Checks if user is logged in
     * @returns {boolean}
     */
    static isUserLoggedIn() {
        if (window.contextHubHandler) {
            return window.contextHubHandler.isLoggedIn();
        } else {
            return false;
        }
    }

    static getAppSettings(cb) {
        window.NativeStorage.getItem("appSettings", function (data) {
                cb(null, data);
            },
            function (error) {
                cb(error, null);
            });
    }

    /**
     *
     * @param settingsObj
     * @param cb
     */
    static updateAppSettings(settingsObj, cb) {
        window.NativeStorage.setItem('appSettings', settingsObj,
            function (persistedObj) {
                cb(null, persistedObj);
            },
            function (error) {
                log.error("DATA LOADED ERROR");
                log.error('ERRORR' + error.code);
                log.error('ERRORR' + error.source);
                log.error('ERRORR' + error.exception);
                cb(error, null);
            });
    }

    /**
     * Checks if appSettings can be loaded from device's native storage. Returns "true" if appSettings were found, otherwise "false"
     * @param cb
     */
    static checkAppSettings(cb) {
        UserDetails.getAppSettings(function(error, settings) {
            if (!error) {
                cb(null, true);
            } else {
                if (error.code === 2) { // error.code = 2 -> requested object was not found
                    cb(null, false);
                } else {
                    cb(error, false);
                }
            }
        });
    }

    /**
     * @param cb
     */
    static createAppSettings(cb) {
        let appSettingsEmpty = {
            selectedShop : '',
            autoLogin: true,
            fingerprintLogin: false,
            fingerprintLoginDecision: '',
            credentials : {
                username: '',
                password: '',
                valid: false
            },
            lastStartup: 0,
            autoLoginTimeout: 30,
            preventAutoLoginForLoggedOutUser: false,
            countForSessionTimeoutMessage: 0,            // Session Timeout Message is shown, when value = 1
            showDialogAskForFingerprintDecision: true
        };

        UserDetails.updateAppSettings(appSettingsEmpty, cb);
    }
}
